labeltools.label_vertical_moments_in_expr_with_numbered_interval_classes
========================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_interval_classes.label_vertical_moments_in_expr_with_numbered_interval_classes
